/*  VER 005  TAB P  $Id: dummy.h,v 1.2.2.1 2003/01/21 09:43:48 egil Exp $
 *
 *  dummy storage-API
 *  used in case nothing is available from INN
 *
 *  $Log: dummy.h,v $
 *  Revision 1.2.2.1  2003/01/21 09:43:48  egil
 *  Updated dummy to do SMerrno
 *
 *  Revision 1.2  1999/04/05 19:01:49  src
 *  Lock for scanlogs
 *
 *  Revision 1.1  1999/03/11 08:00:28  src
 *  Moved from storage
 *
 *  Revision 1.1  1999/03/07 14:58:24  src
 *  Storage API supported.
 */

typedef int BOOL;
#define TRUE 1
#define FALSE 0

typedef int SMSETUP;
#define SM_RDWR 1
#define SM_PREOPEN 2

typedef int RETRTYPE;
#define RETR_ALL 1

typedef struct {
    int dummy;                  /* silly ;-) */
} TOKEN;

typedef struct {
    char *data;
    int len;
    time_t arrived;             /* when article arrived */
} ARTHANDLE;

#define SMERR_NOERROR      0
#define SMERR_NOENT        3
#define SMERR_UNINIT       6
extern int SMerrno;
extern char *SMerrorstr;

BOOL IsToken(const char *text);
TOKEN TextToToken(const char *text);
BOOL SMsetup(SMSETUP type, BOOL *value);
BOOL SMinit(void);
ARTHANDLE * SMretrieve(const TOKEN token, const RETRTYPE amount);
void SMfreearticle(ARTHANDLE *article);
void SMshutdown(void);
